@@ -78,7 +78,6 @@ class QuerySet(object):
 
     >>> with sheraf.connection():
     ...     assert QuerySet([peter]) == Cowboy.all()[0]
-    ...     assert QuerySet([george]) == Cowboy.all()[-1]
     ...     assert QuerySet([peter, steven]) == Cowboy.all()[0:2]
     ...     assert QuerySet([peter, steven, george]) == Cowboy.all()[0:]
     """
@@ -88,6 +87,9 @@ class QuerySet(object):
         self._iterable = iterable
         self._iterator = None
         self._predicate = predicate
+        self._start = None
+        self._stop = None
+        self._step = None
         self.model = model_class
         self.orders = OrderedDict()
 
@@ -134,38 +136,14 @@ class QuerySet(object):
         return QuerySet(difference(OOTreeSet(self), OOTreeSet(other)))
 
     def __getitem__(self, item):
-        self._init_iterator()
+        qs = self.copy()
 
         if isinstance(item, slice):
-            start, stop, step = item.start, item.stop, item.step
+            qs._start, qs._stop, qs._step = item.start, item.stop, item.step
         else:
-            start, stop, step = item, item + 1, 1
+            qs._start, qs._stop, qs._step = item, item + 1, 1
 
-        if self.model:
-            maxid = self.model.count()
-        elif isinstance(self._iterable, Sized):
-            maxid = len(self._iterable)
-        elif (start is None or start >= 0) and (stop is None or stop >= 0):
-            maxid = None
-        else:
-            raise ValueError(
-                "When a QuerySet contains an unknown sized object, slicing values must be > 0"
-            )
-
-        if maxid:
-            if isinstance(item, slice):
-                start = item.start
-                stop = item.stop
-                step = item.step
-                if start and start < 0:
-                    start %= maxid
-                if stop and stop < 0:
-                    stop %= maxid
-            else:
-                start, stop, step = item % maxid, (item % maxid) + 1, 1
-
-        # TODO: Avoid to recreate a QuerySet and avoid itertools.islice
-        return QuerySet(itertools.islice(self._iterator, start, stop, step))
+        return qs
 
     @property
     def indexed_filters(self):
@@ -259,10 +237,17 @@ class QuerySet(object):
                 )
             iterator = iter(iterable)
 
+        # Checks the models fits all the filters
         self._iterator = (
             model for model in iterator if self._model_has_expected_values(model)
         )
 
+        # Only select a slice of the wanted models
+        if self._start is not None or self._stop is not None or self._step is not None:
+            self._iterator = itertools.islice(
+                self._iterator, self._start, self._stop, self._step
+            )
+
     def _model_has_expected_values(self, model):
         if not all(
             getattr(model, filter_name) == expected_value
